@@ -5,9 +5,10 @@ Weight data (manually logged)
 from datetime import datetime
 from typing import NamedTuple, Iterator
 
-from ..common import LazyLogger
-from ..error import Res
-from ..notes import orgmode
+from ..core import LazyLogger
+from ..core.error import Res, set_error_datetime, extract_error_datetime
+
+from .. import orgmode
 
 from my.config import weight as config
 
@@ -24,10 +25,11 @@ class Entry(NamedTuple):
 Result = Res[Entry]
 
 
-# TODO cachew?
 def from_orgmode() -> Iterator[Result]:
     orgs = orgmode.query()
-    for o in orgs.query_all(lambda o: o.with_tag('weight')):
+    for o in orgmode.query().all():
+        if 'weight' not in o.tags:
+            continue
         try:
             # TODO can it throw? not sure
             created = o.created
@@ -39,10 +41,11 @@ def from_orgmode() -> Iterator[Result]:
         try:
             w = float(o.heading)
         except Exception as e:
+            set_error_datetime(e, dt=created)
             log.exception(e)
             yield e
             continue
-        # TODO not sure if it's really necessary..
+        # FIXME use timezone provider
         created = config.default_timezone.localize(created)
         yield Entry(
             dt=created,
@@ -51,13 +54,14 @@ def from_orgmode() -> Iterator[Result]:
         )
 
 
-def dataframe():
+def make_dataframe(data: Iterator[Result]):
     import pandas as pd # type: ignore
-    entries = from_orgmode()
     def it():
-        for e in from_orgmode():
+        for e in data:
             if isinstance(e, Exception):
+                dt = extract_error_datetime(e)
                 yield {
+                    'dt'    : dt,
                     'error': str(e),
                 }
             else:
@@ -67,9 +71,15 @@ def dataframe():
                 }
     df = pd.DataFrame(it())
     df.set_index('dt', inplace=True)
+    # TODO not sure about UTC??
     df.index = pd.to_datetime(df.index, utc=True)
     return df
 
+
+def dataframe():
+    entries = from_orgmode()
+    return make_dataframe(entries)
+
 # TODO move to a submodule? e.g. my.body.weight.orgmode?
 # so there could be more sources
 # not sure about my.body thing though
