@@ -3,6 +3,9 @@ from .common import PathIsh, Paths, Json
 from .common import get_files
 from .common import LazyLogger
 from .common import warn_if_empty
-from .common import stat
+from .common import stat, Stats
 
 from .cfg import make_config
+from .util import __NOT_HPI_MODULE__
+
+from .error import Res, unwrap
