@@ -5,6 +5,7 @@ import functools
 import types
 from typing import Union, Callable, Dict, Iterable, TypeVar, Sequence, List, Optional, Any, cast, Tuple, TYPE_CHECKING
 import warnings
+from . import warnings as core_warnings
 
 # some helper functions
 PathIsh = Union[Path, str]
@@ -111,7 +112,7 @@ def listify(fn=None, wrapper=list):
 #     return listify(fn=fn, wrapper=md)
 
 
-from ..kython.klogging import setup_logger, LazyLogger
+from .logging import setup_logger, LazyLogger
 
 
 Paths = Union[Sequence[PathIsh], PathIsh]
@@ -123,7 +124,6 @@ def _is_compressed(p: Path) -> bool:
     return p.suffix in {'.xz', '.lz4', '.zstd'}
 
 
-# TODO support '' for emtpy path
 DEFAULT_GLOB = '*'
 def get_files(
         pp: Paths,
@@ -168,6 +168,7 @@ def get_files(
                 paths.extend(map(Path, do_glob(ss)))
             else:
                 if not src.is_file():
+                    # todo not sure, might be race condition?
                     raise RuntimeError(f"Expected '{src}' to exist")
                 # todo assert matches glob??
                 paths.append(src)
@@ -177,13 +178,15 @@ def get_files(
 
     if len(paths) == 0:
         # todo make it conditionally defensive based on some global settings
-        # TODO not sure about using warnings module for this
+        core_warnings.high(f'''
+{caller()}: no paths were matched against {pp}. This might result in missing data. Likely, the directory you passed is empty.
+'''.strip())
+        # traceback is useful to figure out what config caused it?
         import traceback
-        warnings.warn(f'{caller()}: no paths were matched against {paths}. This might result in missing data.')
         traceback.print_stack()
 
     if guess_compression:
-        from ..kython.kompress import CPath # todo move to core?
+        from .kompress import CPath
         paths = [CPath(p) if _is_compressed(p) else p for p in paths]
     return tuple(paths)
 
@@ -197,11 +200,22 @@ if TYPE_CHECKING:
     # ok, that's actually a super nice 'pattern'
     F = TypeVar('F')
     class McachewType(Protocol):
-        def __call__(self, cache_path: Any=None, *, hashf: Any=None, chunk_by: int=0, logger: Any=None) -> Callable[[F], F]:
+        def __call__(
+                self,
+                cache_path: Any=None,
+                *,
+                hashf: Any=None, # todo deprecate
+                depends_on: Any=None,
+                force_file: bool=False,
+                chunk_by: int=0,
+                logger: Any=None,
+        ) -> Callable[[F], F]:
             ...
 
     mcachew: McachewType
 
+# TODO set default cache dir here instead?
+# todo ugh. I think it needs doublewrap, otherwise @mcachew without args doesn't work
 def mcachew(*args, **kwargs): # type: ignore[no-redef]
     """
     Stands for 'Maybe cachew'.
@@ -213,8 +227,6 @@ def mcachew(*args, **kwargs): # type: ignore[no-redef]
         warnings.warn('cachew library not found. You might want to install it to speed things up. See https://github.com/karlicoss/cachew')
         return lambda orig_func: orig_func
     else:
-        import cachew.experimental
-        cachew.experimental.enable_exceptions()  # TODO do it only once?
         return cachew.cachew(*args, **kwargs)
 
 
@@ -265,20 +277,31 @@ class classproperty(Generic[_R]):
 #     def __get__(self) -> _R:
 #         return self.f()
 
-# TODO maybe use opaque mypy alias?
+# for now just serves documentation purposes... but one day might make it statically verifiable where possible?
+# TODO e.g. maybe use opaque mypy alias?
 tzdatetime = datetime
 
 
 fromisoformat: Callable[[str], datetime]
 import sys
-if sys.version_info.minor >= 7:
+if sys.version_info[:2] >= (3, 7):
     # prevent mypy on py3.6 from complaining...
-    fromisoformat_real = datetime.fromisoformat # type: ignore[attr-defined]
+    fromisoformat_real = datetime.fromisoformat
     fromisoformat = fromisoformat_real
 else:
     from .py37 import fromisoformat
 
 
+if sys.version_info[:2] >= (3, 8):
+    from typing import Literal
+else:
+    if TYPE_CHECKING:
+        from typing_extensions import Literal
+    else:
+        # erm.. I guess as long as it's not crashing, whatever...
+        Literal = Union
+
+
 # TODO doctests?
 def isoparse(s: str) -> tzdatetime:
     """
@@ -361,37 +384,61 @@ QUICK_STATS = False
 
 
 C = TypeVar('C')
+Stats = Dict[str, Any]
 # todo not sure about return type...
-def stat(func: Callable[[], Iterable[C]]) -> Dict[str, Any]:
+def stat(func: Callable[[], Iterable[C]]) -> Stats:
+    fr = func()
+    tname = type(fr).__name__
+    if tname == 'DataFrame':
+        # dynamic, because pandas is an optional dependency..
+        df = cast(Any, fr) # todo ugh, not sure how to annotate properly
+        res = dict(
+            dtypes=df.dtypes.to_dict(),
+            rows=len(df),
+        )
+    else:
+        res = _stat_iterable(fr)
+    return {
+        func.__name__: res,
+    }
+
+
+def _stat_iterable(it: Iterable[C]) -> Any:
     from more_itertools import ilen, take, first
 
     # todo not sure if there is something in more_itertools to compute this?
+    total = 0
     errors = 0
     last = None
     def funcit():
-        nonlocal errors, last
-        for x in func():
+        nonlocal errors, last, total
+        for x in it:
+            total += 1
             if isinstance(x, Exception):
                 errors += 1
             else:
                 last = x
             yield x
 
-    it = iter(funcit())
+    eit = funcit()
     count: Any
     if QUICK_STATS:
-        initial = take(100, it)
+        initial = take(100, eit)
         count = len(initial)
-        if first(it, None) is not None: # todo can actually be none...
+        if first(eit, None) is not None: # todo can actually be none...
             # haven't exhausted
             count = f'{count}+'
     else:
-        count = ilen(it)
+        count = ilen(eit)
 
     res = {
         'count': count,
     }
 
+    if total == 0:
+        # not sure but I guess a good balance? wouldn't want to throw early here?
+        res['warning'] = 'THE ITERABLE RETURNED NO DATA'
+
     if errors > 0:
         res['errors'] = errors
 
@@ -399,10 +446,7 @@ def stat(func: Callable[[], Iterable[C]]) -> Dict[str, Any]:
         dt = guess_datetime(last)
         if dt is not None:
             res['last'] = dt
-
-    return {
-        func.__name__: res,
-    }
+    return res
 
 
 # experimental, not sure about it..
