@@ -1,13 +1,22 @@
 """
 [[https://hypothes.is][Hypothes.is]] highlights and annotations
 """
+REQUIRES = [
+    'git+https://github.com/karlicoss/hypexport',
+]
 from dataclasses import dataclass
-from typing import Optional
+from datetime import datetime
+from typing import Optional, Callable
 
-from .core import Paths, PathIsh
+from .core import Paths
 
 from my.config import hypothesis as user_config
 
+REQUIRES = [
+    'git+https://github.com/karlicoss/hypexport',
+]
+
+
 
 @dataclass
 class hypothesis(user_config):
@@ -18,30 +27,16 @@ class hypothesis(user_config):
     # paths[s]/glob to the exported JSON data
     export_path: Paths
 
-    # path to a local clone of hypexport
-    # alternatively, you can put the repository (or a symlink) in $MY_CONFIG/my/config/repos/hypexport
-    hypexport  : Optional[PathIsh] = None
-
-    @property
-    def dal_module(self):
-        rpath = self.hypexport
-        if rpath is not None:
-            from .core.common import import_dir
-            return import_dir(rpath, '.dal')
-        else:
-            import my.config.repos.hypexport.dal as dal
-            return dal
-
 
 from .core.cfg import make_config
 config = make_config(hypothesis)
 
 
-from typing import TYPE_CHECKING
-if TYPE_CHECKING:
-    import my.config.repos.hypexport.dal as dal
-else:
-    dal = config.dal_module
+try:
+    from hypexport import dal
+except ModuleNotFoundError as e:
+    from .core.compat import pre_pip_dal_handler
+    dal = pre_pip_dal_handler('hypexport', e, config, requires=REQUIRES)
 
 ############################
 
@@ -59,30 +54,34 @@ def _dal() -> dal.DAL:
 
 
 def highlights() -> List[Res[Highlight]]:
-    return sort_res_by(_dal().highlights(), key=lambda h: h.created)
+    # todo hmm. otherwise mypy complans
+    key: Callable[[Highlight], datetime] = lambda h: h.created
+    return sort_res_by(_dal().highlights(), key=key)
 
 
 # TODO eh. always provide iterators? although sort_res_by could be neat too...
 def pages() -> List[Res[Page]]:
-    return sort_res_by(_dal().pages(), key=lambda h: h.created)
+    # note: mypy report shows "No Anys on this line here", apparently a bug with type aliases
+    # https://github.com/python/mypy/issues/8594
+    key: Callable[[Page], datetime] = lambda h: h.created
+    return sort_res_by(_dal().pages(), key=key)
 
 
 # todo not public api yet
 def stats():
-    # todo add 'last date' checks et
+    from .core import stat
     return {
-        # todo ilen
-        'highlights': len(highlights()),
-        'pages'     : len(pages()),
+        **stat(highlights),
+        **stat(pages),
     }
 
 
-def _main():
+def _main() -> None:
     for page in get_pages():
         print(page)
 
 if __name__ == '__main__':
     _main()
 
-get_highlights = highlights # TODO deprecate
-get_pages = pages # TODO deprecate
+get_highlights = highlights # todo deprecate
+get_pages = pages # todo deprecate
