@@ -6,9 +6,9 @@ def setup_notes_path(notes: Path) -> None:
     from my.cfg import config
 
     class user_config:
-        roots = [notes]
+        paths = [notes]
     config.orgmode = user_config # type: ignore[misc,assignment]
-    # TODO FIXME ugh. this belongs to tz provider or global config or someting
+    # TODO  ugh. this belongs to tz provider or global config or someting
     import pytz
     class user_config_2:
         default_timezone = pytz.timezone('Europe/London')
@@ -33,7 +33,8 @@ def test_dynamic_configuration(notes: Path) -> None:
 import pytest # type: ignore
 
 
-def test_set_repo(tmp_path: Path) -> None:
+# TODO doublt I need it anymore.. keeping for now just for the sake of demonstration
+def _test_set_repo(tmp_path: Path) -> None:
     from my.cfg import config
     class user_config:
         export_path = 'whatever',
@@ -86,7 +87,7 @@ def notes(tmp_path: Path):
 * Weight (org-capture) :weight:
 ** [2020-05-01 Fri 09:00] 62
 ** 63
-    this should be ignored, got no timestmap
+    this should be ignored, got no timestamp
 ** [2020-05-03 Sun 08:00] 61
 ** [2020-05-04 Mon 10:00] 62
     ''')
