@@ -3,9 +3,6 @@ from datetime import datetime
 from itertools import islice
 import pytz
 
-from my.core.cachew import disable_cachew
-disable_cachew()
-
 import my.location.takeout as LT
 from my.google.takeout.html import read_html
 from my.google.takeout.paths import get_last_takeout
@@ -23,7 +20,7 @@ def test_location_perf():
 
 
 # in theory should support any HTML takeout file?
-# although IIRC bookmakrs and search-history.html weren't working
+# although IIRC bookmarks and search-history.html weren't working
 import pytest # type: ignore
 @pytest.mark.parametrize(
     'path', [
@@ -36,6 +33,7 @@ import pytest # type: ignore
 def test_parser(path: str):
     path = 'Takeout/' + path
     tpath = get_last_takeout(path=path)
+    assert tpath is not None
     results = list(read_html(tpath, path))
     # TODO assert len > 100 or something?
     print(len(results))
@@ -44,6 +42,7 @@ def test_parser(path: str):
 def test_myactivity_search():
     path = 'Takeout/My Activity/Search/MyActivity.html'
     tpath = get_last_takeout(path=path)
+    assert tpath is not None
     results = list(read_html(tpath, path))
 
     res = (
