@@ -1,5 +1,4 @@
 # TODO move elsewhere?
-
 # these tests would only make sense with some existing data? although some of them would work for everyone..
 # not sure what's a good way of handling this..
 
@@ -7,7 +6,7 @@ from my.media.youtube import get_watched, Watched
 
 
 def test():
-    watched = get_watched()
+    watched = list(get_watched())
     assert len(watched) > 1000
 
     from datetime import datetime
